@@ -6,5 +6,5 @@ class GeneralisedRushLarsenSecondOrderModel(GeneralisedRushLarsenFirstOrderModel
 
     def __init__(self, model, file_name, **kwargs):
         super().__init__(model, file_name, **kwargs)
-        self._cpp_template = 'generalised_rush_larsen_model_2.cpp'
+        self._templates = ['generalised_rush_larsen_model.hpp', 'generalised_rush_larsen_model_2.cpp']
         self._vars_for_template['model_type'] = 'GeneralizedRushLarsenSecondOrder'
