@@ -6,7 +6,6 @@ class NormalChasteModel(ChasteModel):
 
     def __init__(self, model, file_name, **kwargs):
         super().__init__(model, file_name, **kwargs)
-        self._hpp_template = 'normal_model.hpp'
-        self._cpp_template = 'normal_model.cpp'
+        self._templates = ['normal_model.hpp', 'normal_model.cpp']
         self._vars_for_template['base_class'] = 'AbstractCardiacCell'
         self._vars_for_template['model_type'] = 'Normal'
